@@ -1,9 +1,9 @@
-mod embed;
+mod include_dir;
 mod init;
 
 #[proc_macro]
-pub fn embed(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
-	embed::embed(input.into())
+pub fn include_dir(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
+	include_dir::include_dir(input.into())
 		.unwrap_or_else(|e| e.to_compile_error())
 		.into()
 }
